""" Contains a list of manual translations. Those are usually messages that
exist in external passages which are not queries for i18n extraction.

"""

from onegov.town import _

# messages defined in wtforms-components
_(u"Not a valid color.")
